StormyConfig class

Stormy 统一配置 包含所有模块的配置

Constructors

StormyConfig()

Properties

appConfig Map<String, dynamic>?
应用配置
getter/setter pair
dialog StormyDialogConfig?
弹窗配置
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
i18n StormyI18nConfig?
国际化配置
getter/setter pair
isDialogConfigured bool
no setter
isI18nConfigured bool
no setter
isNetworkConfigured bool
检查是否已配置
no setter
isRefreshConfigured bool
no setter
isStorageConfigured bool
no setter
isThemeConfigured bool
no setter
network StormyNetworkConfig?
网络配置
getter/setter pair
refresh StormyRefreshConfig?
刷新配置
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sdkConfigs Map<String, Map<String, dynamic>>?
SDK 配置
getter/setter pair
storage StormyStorageConfig?
存储配置
getter/setter pair
theme StormyThemeConfig?
主题配置
getter/setter pair

Methods

apply() Future<StormyConfigApplied>
应用配置到各个模块 返回应用结果
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
validate() ConfigValidationResult
验证配置

Operators

operator ==(Object other) bool
The equality operator.
inherited