StormyAssetsConfig class

Dialog Config - 弹窗配置 用于配置对话框、Toast、Loading 等弹窗样式

Constructors

StormyAssetsConfig({String checkIcon = '取消', String unCheckIcon = '取消', String backIcon = '取消'})
const
StormyAssetsConfig.defaultConfig()
创建默认配置
factory

Properties

backIcon String
final
checkIcon String
取消按钮文字
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
unCheckIcon String
final

Methods

copyWith({String? checkIcon, String? unCheckIcon, String? backIcon}) StormyAssetsConfig
复制并修改配置
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited