StormyDialogConfig class
全局 Dialog Config 区分 Alert 和 Confirm 类型的默认配置,同时指定默认弹出位置
Constructors
- StormyDialogConfig({StormyDialogPosition defaultPosition = StormyDialogPosition.bottom, StormyDialogUIConfig alertConfig = const StormyDialogUIConfig(), StormyDialogUIConfig confirmConfig = const StormyDialogUIConfig()})
-
const
- StormyDialogConfig.defaultConfig()
-
获取系统初始默认配置
factory
Properties
- alertConfig → StormyDialogUIConfig
-
单按钮 Alert 弹窗的默认配置
final
- confirmConfig → StormyDialogUIConfig
-
双按钮 Confirm 弹窗的默认配置
final
- defaultPosition → StormyDialogPosition
-
默认弹出位置
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{StormyDialogPosition? defaultPosition, StormyDialogUIConfig? alertConfig, StormyDialogUIConfig? confirmConfig}) → StormyDialogConfig -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited