StormyLoadingConfig class

Loading 配置

Constructors

StormyLoadingConfig({String? message, Color? backgroundColor, double? borderRadius, bool dismissible = false})
const

Properties

backgroundColor Color?
背景色
final
borderRadius double?
圆角半径
final
dismissible bool
是否可关闭
final
hashCode int
The hash code for this object.
no setterinherited
message String?
消息文本
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited