RefreshState enum

刷新状态枚举

Inheritance
Available extensions

Values

ready → const RefreshState

准备就绪

armed → const RefreshState

触发中

processing → const RefreshState

处理中

drag → const RefreshState

拉动中

processed → const RefreshState

处理完成

failed → const RefreshState

失败

noMoreData → const RefreshState

没有更多数据

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<RefreshState>
A constant List of the values in this enum, in order of their declaration.