StormyRefreshConfig class

Refresh Config - 刷新配置 用于配置下拉刷新和上拉加载的相关参数

Constructors

StormyRefreshConfig({double triggerOffset = 44.0, Duration processedDuration = const Duration(milliseconds: 300), double iconDimension = 32.0, double spacing = 0.0, TextStyle? textStyle, TextStyle? messageStyle, StormyRefreshStateTexts? stateTexts, bool showMessage = false, bool safeArea = true, Color? backgroundColor, Color? textColor, StormyRefreshTextConfig? textConfig})
const
StormyRefreshConfig.defaultConfig()
创建默认配置
factory

Properties

backgroundColor Color?
背景颜色 (外部指定优先级最高,若为空取 Theme 值)
final
hashCode int
The hash code for this object.
no setterinherited
iconDimension double
图标尺寸
final
messageStyle TextStyle?
提示消息样式
final
processedDuration Duration
动画处理时长
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
safeArea bool
是否启用安全区域
final
showMessage bool
是否显示提示消息
final
spacing double
间距
final
stateTexts StormyRefreshStateTexts?
各种状态下的提示文本(如果有专门定义优先取这里,如果不指定则使用 textConfig)
final
textColor Color?
文本/图标颜色 (外部指定优先级最高,若为空取 Theme 值)
final
textConfig StormyRefreshTextConfig
文本配置 (默认取中文)
final
textStyle TextStyle?
文本样式
final
triggerOffset double
触发刷新的偏移量
final

Methods

copyWith({double? triggerOffset, Duration? processedDuration, double? iconDimension, double? spacing, TextStyle? textStyle, TextStyle? messageStyle, StormyRefreshStateTexts? stateTexts, bool? showMessage, bool? safeArea, Color? backgroundColor, Color? textColor, StormyRefreshTextConfig? textConfig}) StormyRefreshConfig
复制并修改配置
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited