StormyRefreshStateTexts class

具体状态下的文本配置 用于指定不同刷新状态下的显示文本,优先级高于 StormyRefreshTextConfig

Constructors

StormyRefreshStateTexts({String? ready, String? armed, String? processing, String? drag, String? processed, String? failed, String? noMoreData})
const

Properties

armed String?
触发中
final
drag String?
拉动中
final
failed String?
失败
final
hashCode int
The hash code for this object.
no setterinherited
noMoreData String?
没有更多数据
final
processed String?
处理完成
final
processing String?
处理中
final
ready String?
准备就绪
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? ready, String? armed, String? processing, String? drag, String? processed, String? failed, String? noMoreData}) StormyRefreshStateTexts
复制并修改配置
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited