StormyRefreshTextConfig class

刷新文本配置 用于配置下拉刷新和上拉加载的相关文本内容

Constructors

StormyRefreshTextConfig({String? loading, String? releaseToLoad, String? pullToLoad, String? loadSuccess, String? loadSuccessMessage, String? loadFailed, String? noMoreData, String? lastUpdated})
const
StormyRefreshTextConfig.enUS()
创建默认英文配置
factory
StormyRefreshTextConfig.zhCN()
创建默认中文配置
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
lastUpdated String?
上次更新
final
loadFailed String?
加载失败
final
loading String?
加载中
final
loadSuccess String?
加载成功
final
loadSuccessMessage String?
加载成功消息
final
noMoreData String?
没有更多数据
final
pullToLoad String?
下拉加载
final
releaseToLoad String?
释放加载
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? loading, String? releaseToLoad, String? pullToLoad, String? loadSuccess, String? loadSuccessMessage, String? loadFailed, String? noMoreData, String? lastUpdated}) StormyRefreshTextConfig
复制并修改配置
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited