StormyStorageConfig class
Storage Config - 存储配置 用于配置本地存储的相关参数
Constructors
-
StormyStorageConfig({required List<
StorageBucket> buckets, String? prefix, String? defaultBucketName, void registerAdapters()?}) - StormyStorageConfig.defaultConfig({String bucketName = 'stormy_storage', String? prefix, Object? encryptionCipher, String? storagePath, void registerAdapters()?})
-
创建单 Bucket 默认配置
factory
Properties
-
buckets
→ List<
StorageBucket> -
存储 Bucket 配置列表
final
- defaultBucketName → String
-
默认使用的 Bucket 名称
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- prefix → String?
-
Key前缀
final
- registerAdapters → void Function()?
-
自定义对象适配器注册回调
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{List< StorageBucket> ? buckets, String? prefix, String? defaultBucketName, void registerAdapters()?}) → StormyStorageConfig - 复制并修改配置
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
prefixedKey(
String key) → String - 生成带前缀的Key
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited