build method

  1. @override
Widget build(
  1. BuildContext context
)
override

Describes the part of the user interface represented by this widget.

The framework calls this method when this widget is inserted into the tree in a given BuildContext and when the dependencies of this widget change (e.g., an InheritedWidget referenced by this widget changes). This method can potentially be called in every frame and should not have any side effects beyond building a widget.

The framework replaces the subtree below this widget with the widget returned by this method, either by updating the existing subtree or by removing the subtree and inflating a new subtree, depending on whether the widget returned by this method can update the root of the existing subtree, as determined by calling Widget.canUpdate.

Typically implementations return a newly created constellation of widgets that are configured with information from this widget's constructor and from the given BuildContext.

The given BuildContext contains information about the location in the tree at which this widget is being built. For example, the context provides the set of inherited widgets for this location in the tree. A given widget might be built with multiple different BuildContext arguments over time if the widget is moved around the tree or if the widget is inserted into the tree in multiple places at once.

The implementation of this method must only depend on:

If a widget's build method is to depend on anything else, use a StatefulWidget instead.

See also:

  • StatelessWidget, which contains the discussion on performance considerations.

Implementation

@override
Widget build(BuildContext context) {
  // 使用 useState 确保主题只初始化一次
  final isThemeInitialized = useState(false);
  // 初始化主题(使用 useEffect 避免在 build 期间触发状态更新)
  _initTheme(isThemeInitialized);
  return ScreenUtilInit(
    designSize: AppModel.defaults().designSize,
    minTextAdapt: true,
    ensureScreenSize: true,
    builder: (context, child) {
      return AdaptiveTheme(
        light: StormyTheme.lightThemeData,
        dark: StormyTheme.darkThemeData,
        initial: StormyTheme.adaptiveThemeMode,
        builder: (theme, darkTheme) => ValueListenableBuilder<Locale?>(
          valueListenable: StormyI18n.localeNotifier,
          builder: (context, currentLocale, child) {
            return MaterialApp.router(
              locale: currentLocale,
              localizationsDelegates: StormyConfigAccessor.i18n?.localizationsDelegates,
              supportedLocales: StormyConfigAccessor.i18n?.supportedLocales ?? const <Locale>[Locale('en', 'US')],
              // Router 配置
              routerConfig: router,
              // Theme 配置
              theme: theme,
              darkTheme: darkTheme,
              themeAnimationDuration: const Duration(milliseconds: 500),
              themeAnimationCurve: Curves.easeInOut,
              onGenerateTitle: (context) {
                return appModel.title;
              },
              // UI 配置
              debugShowCheckedModeBanner: false,
              // Smart Dialog 配置(会自动注入 navigatorObservers)
              builder: FlutterSmartDialog.init(
                toastBuilder: appModel.toastBuilder,
                loadingBuilder: appModel.loadingBuilder,
              ),
            );
          },
        ),
      );
    },
  );
}