AppModel class

Constructors

AppModel({required Size designSize, required String title, Widget loadingBuilder(String)?, Widget toastBuilder(String)?})
AppModel.defaults()
factory

Properties

designSize Size
final
hashCode int
The hash code for this object.
no setterinherited
loadingBuilder Widget Function(String)?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
final
toastBuilder Widget Function(String)?
final

Methods

copyWith({Size? designSize, String? title}) AppModel
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited