StormyCommonLocalizationConfig class

Common Localization Config - 通用本地化配置 用于配置通用的文本内容

Constructors

StormyCommonLocalizationConfig({String? noData, String? confirm, String? cancel, String? ok, String? save, String? delete, String? retry, String? error, String? success, String? warmTips})
const
StormyCommonLocalizationConfig.enUS()
创建默认英文配置
factory
StormyCommonLocalizationConfig.zhCN()
创建默认中文配置
factory

Properties

cancel String?
取消
final
confirm String?
确认
final
delete String?
删除
final
error String?
错误
final
hashCode int
The hash code for this object.
no setterinherited
noData String?
暂无数据
final
ok String?
确定
final
retry String?
重试
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
save String?
保存
final
success String?
成功
final
warmTips String?
温馨提示
final

Methods

copyWith({String? noData, String? confirm, String? cancel, String? ok, String? save, String? delete, String? retry, String? error, String? success, String? warmTips}) StormyCommonLocalizationConfig
复制并修改配置
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited