StormyDialogManager class

Dialog Manager - 对话框管理器 提供统一的对话框显示功能

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

hideLoadingDialog(BuildContext context) → void
隐藏加载对话框
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
showBottomSheet<T>({required BuildContext context, required Widget child, bool isDismissible = true, bool enableDrag = true}) Future<T?>
显示底部Sheet
showConfirmDialog({required BuildContext context, required String title, required String content, String confirmText = '确认', String cancelText = '取消', bool isDestructive = false}) Future<bool?>
显示确认对话框
showLoadingDialog({required BuildContext context, String? message}) Future<void>
显示加载对话框
showToast(BuildContext context, String message, {bool isError = false}) → void
显示Toast消息
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance StormyDialogManager
no setter