ThemeDimensions mixin

主题尺寸规范 Mixin 定义所有尺寸相关的属性

Mixin applications

Properties

hashCode int
The hash code for this object.
no setterinherited
mainPadding EdgeInsets
主要内容边距
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
spacingLarge double
大间距
no setter
spacingMedium double
中等间距
no setter
spacingSmall double
小间距
no setter
spacingXLarge double
超大间距
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited