ThemeVariant class abstract
主题变体抽象基类 组合所有主题相关的 Mixin
- Mixed-in types
- Implementers
Constructors
Properties
- appBarTitleStyle → TextStyle
-
AppBar 标题样式
no setterinherited
- background → Color
-
背景色
no setterinherited
- bodyText → Color
-
正文文字颜色
no setterinherited
- borderRadius → double
-
默认圆角
no setterinherited
- brightness → Brightness
-
亮度
no setterinherited
- colorScheme → ColorScheme
-
生成 Material3 ColorScheme
no setterinherited
- contentStyle → TextStyle
-
内容文字样式
no setterinherited
- contentText → Color
-
内容文字颜色(次要文字)
no setterinherited
- error → Color
-
错误色
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- hintStyle → TextStyle
-
提示文字样式
no setterinherited
- hintText → Color
-
提示文字颜色
no setterinherited
- labelStyle → TextStyle
-
标签文字样式
no setterinherited
- labelText → Color
-
标签文字颜色
no setterinherited
- mainPadding → EdgeInsets
-
主要内容边距
no setterinherited
- name → String
-
主题名称
no setter
- outline → Color
-
轮廓色
no setterinherited
- primary → Color
-
主色
no setterinherited
- primaryText → Color
-
主要文字色(特殊浅蓝绿色)
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scaffoldBackground → Color
-
脚手架背景色
no setterinherited
- secondary → Color
-
次要色
no setterinherited
- shadow → Color
-
阴影颜色
no setterinherited
- spacingLarge → double
-
大间距
no setterinherited
- spacingMedium → double
-
中等间距
no setterinherited
- spacingSmall → double
-
小间距
no setterinherited
- spacingXLarge → double
-
超大间距
no setterinherited
- subtitleStyle → TextStyle
-
副标题样式
no setterinherited
- success → Color
-
成功色
no setterinherited
- textStyle → TextStyle
-
普通文本样式
no setterinherited
- titleStyle → TextStyle
-
大标题样式
no setterinherited
- variantTextTheme → TextTheme
-
no setterinherited
- warning → Color
-
警告色
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
toThemeData(
) → ThemeData - 转换为 Material ThemeData
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited