ListSelectController<T> class

选择控制器(供父组件使用)

Inheritance

Constructors

ListSelectController()

Properties

hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
hasSelection bool
是否有选中项
no setter
isSelectMode bool
是否处于选择模式
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedCount int
获取已选中的数量
no setter
selectedIds Set<String>
获取已选中的 ID 集合
no setter

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
deselectAll() → void
取消全选
deselectItem(String id) → void
取消选中单个项目
dispose() → void
Discards any resources used by the object.
inherited
exitSelectMode() → void
退出选择模式并清空选择
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
selectAll(List<String> ids) → void
全选
selectAllByItems(List<T> items, String getId(T)) → void
通过项目列表全选
selectItem(String id) → void
选中单个项目
setSelectMode(bool value) → void
设置选择模式
toggleSelection(String id) → void
切换单个项目选择状态
toggleSelectMode() → void
切换选择模式
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited