ListSelectState<T> class

选择状态管理器

Inheritance

Constructors

ListSelectState({bool isSelectMode = false, Set<String>? selectedIds})

Properties

hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
hasSelection bool
no setter
isSelectMode bool
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedCount int
no setter
selectedIds Set<String>
no setter

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
clearSelection() → void
deselectItem(String id) → void
dispose() → void
Discards any resources used by the object.
inherited
isItemSelected(String id) bool
isItemSelectedByItem(T item, String getId(T)) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
selectAll(List<String> ids) → void
selectItem(String id) → void
setSelectMode(bool value) → void
toggleSelection(String id) → void
toggleSelectMode() → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited