RetryDelayStrategy enum
重试延迟策略
Values
- fixed → const RetryDelayStrategy
-
固定延迟,每次等待相同时间
- linear → const RetryDelayStrategy
-
线性递增,每次数组索引越大延迟越长
- exponential → const RetryDelayStrategy
-
指数退避,每次延迟翻倍(越来越慢)
- decay → const RetryDelayStrategy
-
指数衰减,delayFactor < 1 时越来越快
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
RetryDelayStrategy> - A constant List of the values in this enum, in order of their declaration.