PreloadManagerState enum

预加载管理器整体状态

Inheritance
Available extensions

Values

idle → const PreloadManagerState

空闲状态

running → const PreloadManagerState

正在执行

completed → const PreloadManagerState

执行完成

failed → const PreloadManagerState

执行失败

cancelled → const PreloadManagerState

已取消

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<PreloadManagerState>
A constant List of the values in this enum, in order of their declaration.