PreloadResult enum
预加载结果
Values
- success → const PreloadResult
-
成功
- partialSuccess → const PreloadResult
-
部分成功(某些非必需任务失败)
- failed → const PreloadResult
-
失败
- cancelled → const PreloadResult
-
取消
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
PreloadResult> - A constant List of the values in this enum, in order of their declaration.