PermissonTips class

Constructors

PermissonTips({required String? title, required String? content, required String? confirmText, required String? deniedText, required String? permanentlyDeniedText})

Properties

confirmText String?
final
content String?
final
deniedText String?
final
hashCode int
The hash code for this object.
no setterinherited
permanentlyDeniedText String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited