BaseImage class

Inheritance

Constructors

BaseImage({Key? key, required String url, double width = double.infinity, double? height, double? maxWidth, double? maxHeight, BoxFit fit = BoxFit.cover, double radius = 0, Color? baseColor = const Color(0xFFDEE6FD), Color? highlightColor, bool? noLoading = false, bool showThumbnail = false, bool autoHeight = false, double? aspectRatio})
const
BaseImage.asset(String assetPath, {Key? key, double width = double.infinity, double? height, double? maxWidth, double? maxHeight, BoxFit fit = BoxFit.cover, double radius = 0, Color? baseColor = const Color(0xFFDEE6FD), Color? highlightColor, bool? noLoading = false, bool showThumbnail = false, bool autoHeight = false, double? aspectRatio})
展示 assets 中的静态图片
const
BaseImage.file(File file, {Key? key, double width = double.infinity, double? height, double? maxWidth, double? maxHeight, BoxFit fit = BoxFit.cover, double radius = 0, Color? baseColor = const Color(0xFFDEE6FD), Color? highlightColor, bool? noLoading = false, bool showThumbnail = false, bool autoHeight = false, double? aspectRatio})
展示文件系统中的静态图片

Properties

aspectRatio double?
final
autoHeight bool
final
baseColor Color?
final
fit BoxFit
final
hashCode int
The hash code for this object.
no setterinherited
height double?
final
highlightColor Color?
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
maxHeight double?
final
maxWidth double?
final
noLoading bool?
final
radius double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showThumbnail bool
final
url String
final
width double
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<BaseImage>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited