IndicatorAlignment enum

Indicator 对齐方式

Inheritance
Available extensions

Values

start → const IndicatorAlignment

左对齐:indicator 与 label 左边对齐

center → const IndicatorAlignment

居中对齐:indicator 在 label 下方居中(默认)

end → const IndicatorAlignment

右对齐:indicator 与 label 右边对齐

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<IndicatorAlignment>
A constant List of the values in this enum, in order of their declaration.