widgets/special/before_after/src/before_after library
Classes
- BeforeAfter
- An interactive widget that allows comparing two images using a before and after view.
- Hide
- A widget that hides its child widget from being visible.
- TwoDirectionalSlider
- A widget that allows interactive two-directional sliding gestures.
Enums
- SliderDirection
- The direction in which slider can be dragged.