AgreeItemModel class

协议项模型,包含协议名称和URL

Constructors

AgreeItemModel({required String label, required String agreeUrl})
const

Properties

agreeUrl String
协议URL地址
final
hashCode int
The hash code for this object.
no setterinherited
label String
协议标签名称 (如《用户协议》)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited