ProtocolSegment class

协议链接分段

Inheritance

Constructors

ProtocolSegment(AgreeItemModel protocol, {TextStyle? style, VoidCallback? onTap})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
onTap VoidCallback?
自定义点击事件,如果为空则走组件默认事件
final
protocol AgreeItemModel
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
style TextStyle?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited