PrivacyDialogConfig class

弹窗整体外层配置

Constructors

PrivacyDialogConfig({PrivacyHeaderConfig header = const PrivacyHeaderConfig(), PrivacyBodyConfig body = const PrivacyBodyConfig(), PrivacyFooterConfig footer = const PrivacyFooterConfig(), PrivacyExitConfirmConfig exitConfirm = const PrivacyExitConfirmConfig(), Color? backgroundColor, double? width, EdgeInsetsGeometry? padding, BorderRadiusGeometry? borderRadius})
const

Properties

backgroundColor Color?
final
body PrivacyBodyConfig
final
borderRadius BorderRadiusGeometry?
final
exitConfirm PrivacyExitConfirmConfig
final
final
hashCode int
The hash code for this object.
no setterinherited
final
padding EdgeInsetsGeometry?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
width double?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited