PrivacyHeaderConfig class

头部配置

Constructors

PrivacyHeaderConfig({String title = '服务协议和隐私条款', double? fontSize, FontWeight? fontWeight = FontWeight.w600, Color? color})
const

Properties

color Color?
final
fontSize double?
final
fontWeight FontWeight?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited