widgets/widgets library
Classes
- AgreeItemModel
- 协议项模型,包含协议名称和URL
- AgreementCheckbox
- 协议复选框组件
- AgreementSegment
- 协议分段基础类
- AgreementWidget
- 协议同意组件
- BaseAppBar
- BaseBottomPadding
- 底部填充区域(自动计算)
- BaseBottomSheet
- 基础底部弹窗组件
- BaseButton
- BaseConfirm
- BaseImage
- BaseInput
- BaseLoad
- BasePage
- 基础页面壳体,统一封装页面的返回拦截、滚动控制与 EasyRefresh 集成逻辑。
- BaseParent
- BaseTabBar
- 自定义 TabBar 组件
- BeforeAfter
- An interactive widget that allows comparing two images using a before and after view.
- BeforeAfterTheme
- A theme extension class that defines custom styling and behavior for the BeforeAfter widget.
- CornerFiller
- 圆角填充器 - 用于创建凹角效果
- CustomLoading
- CustomToast
- EasyRefreshConfig
- EasyRefresh 的参数封装,便于按需开启刷新能力。
- EVDottedLineBorder
- FlexibleSpaceLayout
- 使用 flexibleSpace 实现的灵活布局 优点:
- GrowTransition
- H5
- Hide
- A widget that hides its child widget from being visible.
- PrivacyBodyConfig
- 主体配置
- PrivacyDialogConfig
- 弹窗整体外层配置
- PrivacyExitConfirmConfig
- 确认退出弹窗配置
- 底部配置
- PrivacyHeaderConfig
- 头部配置
- PrivacyPolicyDialog
- ProtocolSegment
- 协议链接分段
- StormyAlertDialog
- 统一样式的 Alert(提示)对话框 UI 组件 - 纯 UI 的 stateless
- StormyConfirmDialog
- 统一样式的 Confirm(确认)对话框 UI 组件 - 纯 UI 的 stateless
- StormyPrivacyConfig
- 隐私协议全局配置防腐层
- TextSegment
- 纯文本分段
- TwoDirectionalSlider
- A widget that allows interactive two-directional sliding gestures.
Enums
- CornerPosition
- 凹角位置枚举
- IndicatorAlignment
- Indicator 对齐方式
- SliderDirection
- The direction in which slider can be dragged.
- ValidationState
- 校验状态
Functions
-
baseShowConfirm(
String title, String content, dynamic onCancel()?, dynamic onConfirm()?) → Future< bool> -
showBaseBottomSheet(
BuildContext context, {required Widget child, double minHeight = 0.5, double maxHeight = 0.8, Color? maskColor, bool isDismissible = true, bool enableDrag = true, VoidCallback? onDismiss}) → Future< bool?> - 显示底部弹窗的便捷方法