StormyConfigApplied class
应用配置结果 用于存储配置应用后的状态
Constructors
Properties
- dialogApplied → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isAllApplied → bool
-
no setter
- localizationApplied → bool
-
final
- networkApplied → bool
-
final
- refreshApplied → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
sdkApplied
→ List<
String> -
final
- storageApplied → bool
-
final
- themeApplied → bool
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited