StormyDialogConfig class

Dialog Config - 弹窗配置 用于配置对话框、Toast、Loading 等弹窗样式

Constructors

StormyDialogConfig({Color? backgroundColor, double? borderRadius, TextStyle? titleStyle, TextStyle? messageStyle, ButtonStyle? confirmButtonStyle, ButtonStyle? cancelButtonStyle, String confirmText = '确认', String cancelText = '取消', Color? barrierColor, bool barrierDismissible = false})
const
StormyDialogConfig.defaultConfig()
创建默认配置
factory

Properties

backgroundColor Color?
背景色
final
barrierColor Color?
遮罩层颜色
final
barrierDismissible bool
是否可点击遮罩关闭
final
borderRadius double?
圆角半径
final
cancelButtonStyle ButtonStyle?
取消按钮样式
final
cancelText String
取消按钮文字
final
confirmButtonStyle ButtonStyle?
确认按钮样式
final
confirmText String
确认按钮文字
final
hashCode int
The hash code for this object.
no setterinherited
messageStyle TextStyle?
内容文本样式
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
titleStyle TextStyle?
标题文本样式
final

Methods

copyWith({Color? backgroundColor, double? borderRadius, TextStyle? titleStyle, TextStyle? messageStyle, ButtonStyle? confirmButtonStyle, ButtonStyle? cancelButtonStyle, String? confirmText, String? cancelText, Color? barrierColor, bool? barrierDismissible}) StormyDialogConfig
复制并修改配置
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited