StormyLocalizationConfig class
Stormy 本地化配置 用于配置 Stormy 模块的文本内容 参考 StormyThemeConfig 的设计模式:高内聚,外部可覆盖
Constructors
- StormyLocalizationConfig({StormyCommonLocalizationConfig? common, StormyRefreshLocalizationConfig? refresh})
-
const
- StormyLocalizationConfig.defaults()
-
创建默认配置(中文)
factory
- StormyLocalizationConfig.enUS()
-
创建默认英文配置
factory
- StormyLocalizationConfig.zhCN()
-
创建默认中文配置
factory
Properties
- common → StormyCommonLocalizationConfig?
-
通用本地化配置
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- refresh → StormyRefreshLocalizationConfig?
-
刷新模块本地化配置
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{StormyCommonLocalizationConfig? common, StormyRefreshLocalizationConfig? refresh}) → StormyLocalizationConfig - 复制并修改配置
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited