StormyRefreshConfig class

Refresh Config - 刷新配置 用于配置下拉刷新和上拉加载的相关参数

Constructors

StormyRefreshConfig({double triggerOffset = 44.0, Duration processedDuration = const Duration(milliseconds: 300), double iconDimension = 32.0, double spacing = 0.0, TextStyle? textStyle, TextStyle? messageStyle, Map<RefreshState, String>? stateTexts, bool showMessage = false, bool safeArea = true})
const
StormyRefreshConfig.defaultConfig()
创建默认配置
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
iconDimension double
图标尺寸
final
messageStyle TextStyle?
提示消息样式
final
processedDuration Duration
动画处理时长
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
safeArea bool
是否启用安全区域
final
showMessage bool
是否显示提示消息
final
spacing double
间距
final
stateTexts Map<RefreshState, String>?
各种状态下的提示文本
final
textStyle TextStyle?
文本样式
final
triggerOffset double
触发刷新的偏移量
final

Methods

copyWith({double? triggerOffset, Duration? processedDuration, double? iconDimension, double? spacing, TextStyle? textStyle, TextStyle? messageStyle, Map<RefreshState, String>? stateTexts, bool? showMessage, bool? safeArea}) StormyRefreshConfig
复制并修改配置
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited