StormyStorageConfig class

Storage Config - 存储配置 用于配置本地存储的相关参数

Constructors

StormyStorageConfig({String boxName = 'stormy_storage', String? prefix, bool encrypted = false, String? storagePath})
const
StormyStorageConfig.defaultConfig({String boxName = 'stormy_storage', String? prefix})
创建默认配置
factory

Properties

boxName String
存储Box名称
final
encrypted bool
是否加密存储
final
hashCode int
The hash code for this object.
no setterinherited
prefix String?
Key前缀
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
storagePath String?
存储路径(可选,用于指定存储目录)
final

Methods

copyWith({String? boxName, String? prefix, bool? encrypted, String? storagePath}) StormyStorageConfig
复制并修改配置
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
prefixedKey(String key) String
生成带前缀的Key
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited