PreloadEngine class
预加载执行引擎 — 封装任务验证、依赖解析、执行、重试逻辑
Constructors
- PreloadEngine({PreloadConfig? config, PreloadTracker? tracker, PreloadSemaphore? semaphore})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
cancel(
) → void - 取消执行
-
execute(
List< PreloadTask> tasks, {ProviderContainer? container}) → Future<PreloadExecutionResult> - 执行预加载任务
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited