PreloadExecutionResult class
预加载执行结果
Constructors
-
PreloadExecutionResult({required PreloadResult result, required int completedTasks, required int failedTasks, required int totalTasks, required Map<
String, Object> failedTaskDetails, required Duration executionTime}) -
const
Properties
- completedTasks → int
-
成功完成的任务数
final
- executionTime → Duration
-
执行耗时
final
-
failedTaskDetails
→ Map<
String, Object> -
失败的任务详情
final
- failedTasks → int
-
失败的任务数
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isCompleteSuccess → bool
-
是否完全成功
no setter
- isPartialSuccess → bool
-
是否部分成功
no setter
- result → PreloadResult
-
执行结果
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- successRate → double
-
成功率
no setter
- totalTasks → int
-
总任务数
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited