TaskConfig class
Constructors
- TaskConfig({int priority = 1, bool required = true, Duration? timeout, String? name})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String?
-
任务名称(用于日志和调试)
final
- priority → int
-
任务优先级(数字越大优先级越高)
final
- required → bool
-
任务是否必需(必需任务失败会导致整体失败)
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timeout → Duration?
-
任务超时时间(null 表示使用全局配置)
final
Methods
-
copyWith(
{int? priority, bool? required, Duration? timeout, String? name}) → TaskConfig - 创建副本并修改部分配置
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited