PreloadManager class
预加载管理器 — Facade 模式,负责任务注册、状态流转、对外 API
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
progress
→ Stream<
PreloadProgress> -
获取当前进度流
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state → PreloadManagerState
-
获取当前状态
no setter
Methods
-
cancel(
) → void - 取消当前执行
-
clear(
) → void - 清空所有注册的任务
-
configure(
PreloadConfig config) → void - 配置管理
-
execute(
{ProviderContainer? container}) → Future< PreloadExecutionResult> - 执行预加载
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
register<
T> (T target, {String? name, List< String> dependencies = const [], Future<bool> checkBeforeExecute()?, Duration? checkRetryDelay, int maxCheckRetries = 10, int priority = 1, bool required = true, Duration? timeout}) → PreloadManager - 注册预加载任务 — 智能识别 Provider 或普通方法
-
registerBatch(
List< PreloadTask> tasks) → PreloadManager - 批量注册任务
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance → PreloadManager
-
no setter