AppUtils class
Constructors
- AppUtils()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- deviceIdentifier → DeviceIdentifierPlugin
-
final
- deviceInfoPlugin → DeviceInfoPlugin
-
final
Static Methods
-
getAdId(
) → Future< String?> - 获取adID(区分安卓和iOS)
-
getAndroidId(
) → Future< String?> - 获取 AndroidId
-
getAppleIDFV(
) → Future< String?> - 获取iOS IDFV
-
getAppName(
) → Future< String> - App名称
-
getBaseDeviceId(
) → Future< String?> - 获取 AndroidId
-
getBuildSignature(
) → Future< String> - 获取App构建签名 在 iOS 上为空字符串,在 Android 上为密钥签名(十六进制)
-
getDeviceBrand(
) → Future< String> -
getDeviceModel(
) → Future< String> - 获取设备型号 返回如 "iPhone 12, Pixel 5, Huawei P40" 这样的字符串
-
getDeviceUniqueId(
) → Future< String?> - 获取设备唯一标识(AndroidId或iOS唯一标识)
-
getInstallerStore(
) → Future< String> - 获取App安装商店 若是通过应用商店安装的应用,返回应用商店的名称,否则返回空字符串
-
getIosIDFAId(
) → Future< String?> - 获取iOS IDFA
-
getIosUniqueId(
) → Future< String?> - 获取 iOS 唯一标识 优先读取 KeyChain 缓存,失败时依次尝试 IDFA、IDFV,最后生成本地 UUID 保存
-
getPackageName(
) → Future< String> - 包名
-
getSystemVersion(
) → Future< String> -
getVersionName(
) → Future< String> - 版本名
-
getVersionNumber(
) → Future< String> - 版本号