PrivacyBodyConfig class
主体配置
Constructors
-
PrivacyBodyConfig({double? minHeight, double? maxHeight, TextStyle? normalTextStyle, TextStyle? highlightTextStyle, List<
String> contentParagraphs = const ['感谢您信任并使用我们的产品。', '当您使用本APP时,请仔细务必仔细阅读、充分理解用户协议和隐私政策各条款,包括但不限于用户注意事项,用户行为规范以及为向您提供服务而收集、使用、存储您个人信息的情况。'], String userAgreementName = '《用户协议》', String privacyPolicyName = '《隐私政策》', String userAgreementUrl = 'https://example.com/agreement', String privacyPolicyUrl = 'https://example.com/privacy'}) -
const
Properties
-
contentParagraphs
→ List<
String> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- highlightTextStyle → TextStyle?
-
final
- maxHeight → double?
-
final
- minHeight → double?
-
final
- normalTextStyle → TextStyle?
-
final
- privacyPolicyName → String
-
final
- privacyPolicyUrl → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- userAgreementName → String
-
final
- userAgreementUrl → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited