widgets/widgets library
Classes
- AgreeItem
- 协议链接项
- AgreeItemModel
- 协议项模型,包含协议名称和URL
- AgreementCheckbox
- 协议复选框组件
- AgreementUtils
- 协议工具类
- AgreementWidget
- 协议同意组件
- BaseAppBar
- BaseBottomPadding
- 底部填充区域(自动计算)
- BaseBottomSheet
- 基础底部弹窗组件
- BaseButton
- BaseConfirm
- BaseImage
- BaseInput
- BaseLoad
- BasePage
- 基础页面壳体,统一封装页面的返回拦截、滚动控制与 EasyRefresh 集成逻辑。
- BaseParent
- BaseTabBar
- 自定义 TabBar 组件
- BeforeAfter
- An interactive widget that allows comparing two images using a before and after view.
- BeforeAfterTheme
- A theme extension class that defines custom styling and behavior for the BeforeAfter widget.
- CenterAlertDialog
- CenterConfirmDialog
- CornerFiller
- 圆角填充器 - 用于创建凹角效果
- EasyRefreshConfig
- EasyRefresh 的参数封装,便于按需开启刷新能力。
- EVDottedLineBorder
- FlexibleSpaceLayout
- 使用 flexibleSpace 实现的灵活布局 优点:
- GrowTransition
- H5
- Hide
- A widget that hides its child widget from being visible.
- PrivacyPolicyDialog
- PrivacyPolicyUtils
- TwoDirectionalSlider
- A widget that allows interactive two-directional sliding gestures.
Enums
- CornerPosition
- 凹角位置枚举
- IndicatorAlignment
- Indicator 对齐方式
- SliderDirection
- The direction in which slider can be dragged.
- ValidationState
- 校验状态
Properties
- showAgreeId ↔ Map
-
getter/setter pair
- showAlertId ↔ Map
-
getter/setter pair
Functions
-
baseShowConfirm(
String title, String content, dynamic onCancel()?, dynamic onConfirm()?) → Future< bool> -
buildTextContent(
List< InlineSpan> children) → Widget - 构建文本内容
-
showAgree(
BuildContext context, {required String id, String buttonMsg = 'continue', required List< InlineSpan> children, bool enableDrag = false, Color? buttonColor, Color? textColor}) → Future<bool> -
showAlert(
BuildContext context, {required String message, required String id, String? title, Widget? child, String buttonMsg = '确认'}) → Future< bool?> -
showAlertDialog(
BuildContext context, {String? title, String? content, VoidCallback? onConfirm, String? confirmText, Widget? child}) → Future< bool> -
showBaseBottomSheet(
BuildContext context, {required Widget child, double minHeight = 0.5, double maxHeight = 0.8, Color? maskColor, bool isDismissible = true, bool enableDrag = true, VoidCallback? onDismiss}) → Future< bool?> - 显示底部弹窗的便捷方法
-
showConfirmDialog(
String title, String content, {VoidCallback? onConfirm, VoidCallback? onCancel, bool? useSystem, String? confirmText, String? cancelText}) → Future< bool> -
showExitConfirmDialog(
BuildContext context, VoidCallback onCancel, Function onConfirm) → Future< bool> - 显示退出确认弹窗